Improve this Doc View Source

Mock implementation of the `$animate` service. Exposes two additional methods for testing animations.

You need to require the `ngAnimateMock` module in your test suite for instance `beforeEach(module('ngAnimateMock'))`

## Methods

- ###

  `closeAndFlush();`

  This method will close all pending animations (both Javascript and CSS) and it will also flush any remaining animation frames and/or callbacks.

- ###

  `flush();`

  This method is used to flush the pending callbacks and animation frames to either start an animation or conclude an animation. Note that this will not actually close an actively running animation (see `closeAndFlush()` for that).